# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['DomainRecordArgs', 'DomainRecord']

@pulumi.input_type
class DomainRecordArgs:
    def __init__(__self__, *,
                 content: pulumi.Input[str],
                 domain: pulumi.Input[str],
                 record_type: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None,
                 prio: Optional[pulumi.Input[int]] = None,
                 ttl: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a DomainRecord resource.
        :param pulumi.Input[str] content: The record value.
        :param pulumi.Input[str] domain: The parent Domain to attach the record to.
        :param pulumi.Input[str] record_type: The record type (`A`, `AAAA`, `ALIAS`, `CAA`, `CNAME`, `HINFO`, `MX`, `NAPTR`, `NS`, `POOL`, `SPF`, `SRV`, `SSHFP`, `TXT`, `URL`).
        :param pulumi.Input[str] name: The record name, Leave blank (`""`) to create a root record (similar to using `@` in a DNS zone file).
        :param pulumi.Input[int] prio: The record priority (for types that support it; minimum `0`).
        :param pulumi.Input[int] ttl: The record TTL (seconds; minimum `0`; default: `3600`).
        """
        pulumi.set(__self__, "content", content)
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "record_type", record_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if prio is not None:
            pulumi.set(__self__, "prio", prio)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)

    @property
    @pulumi.getter
    def content(self) -> pulumi.Input[str]:
        """
        The record value.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: pulumi.Input[str]):
        pulumi.set(self, "content", value)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[str]:
        """
        The parent Domain to attach the record to.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="recordType")
    def record_type(self) -> pulumi.Input[str]:
        """
        The record type (`A`, `AAAA`, `ALIAS`, `CAA`, `CNAME`, `HINFO`, `MX`, `NAPTR`, `NS`, `POOL`, `SPF`, `SRV`, `SSHFP`, `TXT`, `URL`).
        """
        return pulumi.get(self, "record_type")

    @record_type.setter
    def record_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "record_type", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The record name, Leave blank (`""`) to create a root record (similar to using `@` in a DNS zone file).
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def prio(self) -> Optional[pulumi.Input[int]]:
        """
        The record priority (for types that support it; minimum `0`).
        """
        return pulumi.get(self, "prio")

    @prio.setter
    def prio(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "prio", value)

    @property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The record TTL (seconds; minimum `0`; default: `3600`).
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ttl", value)


@pulumi.input_type
class _DomainRecordState:
    def __init__(__self__, *,
                 content: Optional[pulumi.Input[str]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 hostname: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 prio: Optional[pulumi.Input[int]] = None,
                 record_type: Optional[pulumi.Input[str]] = None,
                 ttl: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering DomainRecord resources.
        :param pulumi.Input[str] content: The record value.
        :param pulumi.Input[str] domain: The parent Domain to attach the record to.
        :param pulumi.Input[str] hostname: The record *Fully Qualified Domain Name* (FQDN). Useful for aliasing `A`/`AAAA` records with `CNAME`.
        :param pulumi.Input[str] name: The record name, Leave blank (`""`) to create a root record (similar to using `@` in a DNS zone file).
        :param pulumi.Input[int] prio: The record priority (for types that support it; minimum `0`).
        :param pulumi.Input[str] record_type: The record type (`A`, `AAAA`, `ALIAS`, `CAA`, `CNAME`, `HINFO`, `MX`, `NAPTR`, `NS`, `POOL`, `SPF`, `SRV`, `SSHFP`, `TXT`, `URL`).
        :param pulumi.Input[int] ttl: The record TTL (seconds; minimum `0`; default: `3600`).
        """
        if content is not None:
            pulumi.set(__self__, "content", content)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if prio is not None:
            pulumi.set(__self__, "prio", prio)
        if record_type is not None:
            pulumi.set(__self__, "record_type", record_type)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)

    @property
    @pulumi.getter
    def content(self) -> Optional[pulumi.Input[str]]:
        """
        The record value.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[str]]:
        """
        The parent Domain to attach the record to.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[str]]:
        """
        The record *Fully Qualified Domain Name* (FQDN). Useful for aliasing `A`/`AAAA` records with `CNAME`.
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hostname", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The record name, Leave blank (`""`) to create a root record (similar to using `@` in a DNS zone file).
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def prio(self) -> Optional[pulumi.Input[int]]:
        """
        The record priority (for types that support it; minimum `0`).
        """
        return pulumi.get(self, "prio")

    @prio.setter
    def prio(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "prio", value)

    @property
    @pulumi.getter(name="recordType")
    def record_type(self) -> Optional[pulumi.Input[str]]:
        """
        The record type (`A`, `AAAA`, `ALIAS`, `CAA`, `CNAME`, `HINFO`, `MX`, `NAPTR`, `NS`, `POOL`, `SPF`, `SRV`, `SSHFP`, `TXT`, `URL`).
        """
        return pulumi.get(self, "record_type")

    @record_type.setter
    def record_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "record_type", value)

    @property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[int]]:
        """
        The record TTL (seconds; minimum `0`; default: `3600`).
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ttl", value)


class DomainRecord(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content: Optional[pulumi.Input[str]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 prio: Optional[pulumi.Input[int]] = None,
                 record_type: Optional[pulumi.Input[str]] = None,
                 ttl: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        ## Import

        An existing DNS domain record may be imported by `<ID>`console

        ```sh
         $ pulumi import exoscale:index/domainRecord:DomainRecord \\
        ```

         exoscale_domain_record.my_host \\

         f81d4fae-7dec-11d0-a765-00a0c91e6bf6

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] content: The record value.
        :param pulumi.Input[str] domain: The parent Domain to attach the record to.
        :param pulumi.Input[str] name: The record name, Leave blank (`""`) to create a root record (similar to using `@` in a DNS zone file).
        :param pulumi.Input[int] prio: The record priority (for types that support it; minimum `0`).
        :param pulumi.Input[str] record_type: The record type (`A`, `AAAA`, `ALIAS`, `CAA`, `CNAME`, `HINFO`, `MX`, `NAPTR`, `NS`, `POOL`, `SPF`, `SRV`, `SSHFP`, `TXT`, `URL`).
        :param pulumi.Input[int] ttl: The record TTL (seconds; minimum `0`; default: `3600`).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DomainRecordArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        An existing DNS domain record may be imported by `<ID>`console

        ```sh
         $ pulumi import exoscale:index/domainRecord:DomainRecord \\
        ```

         exoscale_domain_record.my_host \\

         f81d4fae-7dec-11d0-a765-00a0c91e6bf6

        :param str resource_name: The name of the resource.
        :param DomainRecordArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DomainRecordArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content: Optional[pulumi.Input[str]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 prio: Optional[pulumi.Input[int]] = None,
                 record_type: Optional[pulumi.Input[str]] = None,
                 ttl: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DomainRecordArgs.__new__(DomainRecordArgs)

            if content is None and not opts.urn:
                raise TypeError("Missing required property 'content'")
            __props__.__dict__["content"] = content
            if domain is None and not opts.urn:
                raise TypeError("Missing required property 'domain'")
            __props__.__dict__["domain"] = domain
            __props__.__dict__["name"] = name
            __props__.__dict__["prio"] = prio
            if record_type is None and not opts.urn:
                raise TypeError("Missing required property 'record_type'")
            __props__.__dict__["record_type"] = record_type
            __props__.__dict__["ttl"] = ttl
            __props__.__dict__["hostname"] = None
        super(DomainRecord, __self__).__init__(
            'exoscale:index/domainRecord:DomainRecord',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            content: Optional[pulumi.Input[str]] = None,
            domain: Optional[pulumi.Input[str]] = None,
            hostname: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            prio: Optional[pulumi.Input[int]] = None,
            record_type: Optional[pulumi.Input[str]] = None,
            ttl: Optional[pulumi.Input[int]] = None) -> 'DomainRecord':
        """
        Get an existing DomainRecord resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] content: The record value.
        :param pulumi.Input[str] domain: The parent Domain to attach the record to.
        :param pulumi.Input[str] hostname: The record *Fully Qualified Domain Name* (FQDN). Useful for aliasing `A`/`AAAA` records with `CNAME`.
        :param pulumi.Input[str] name: The record name, Leave blank (`""`) to create a root record (similar to using `@` in a DNS zone file).
        :param pulumi.Input[int] prio: The record priority (for types that support it; minimum `0`).
        :param pulumi.Input[str] record_type: The record type (`A`, `AAAA`, `ALIAS`, `CAA`, `CNAME`, `HINFO`, `MX`, `NAPTR`, `NS`, `POOL`, `SPF`, `SRV`, `SSHFP`, `TXT`, `URL`).
        :param pulumi.Input[int] ttl: The record TTL (seconds; minimum `0`; default: `3600`).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DomainRecordState.__new__(_DomainRecordState)

        __props__.__dict__["content"] = content
        __props__.__dict__["domain"] = domain
        __props__.__dict__["hostname"] = hostname
        __props__.__dict__["name"] = name
        __props__.__dict__["prio"] = prio
        __props__.__dict__["record_type"] = record_type
        __props__.__dict__["ttl"] = ttl
        return DomainRecord(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def content(self) -> pulumi.Output[str]:
        """
        The record value.
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[str]:
        """
        The parent Domain to attach the record to.
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter
    def hostname(self) -> pulumi.Output[str]:
        """
        The record *Fully Qualified Domain Name* (FQDN). Useful for aliasing `A`/`AAAA` records with `CNAME`.
        """
        return pulumi.get(self, "hostname")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The record name, Leave blank (`""`) to create a root record (similar to using `@` in a DNS zone file).
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def prio(self) -> pulumi.Output[int]:
        """
        The record priority (for types that support it; minimum `0`).
        """
        return pulumi.get(self, "prio")

    @property
    @pulumi.getter(name="recordType")
    def record_type(self) -> pulumi.Output[str]:
        """
        The record type (`A`, `AAAA`, `ALIAS`, `CAA`, `CNAME`, `HINFO`, `MX`, `NAPTR`, `NS`, `POOL`, `SPF`, `SRV`, `SSHFP`, `TXT`, `URL`).
        """
        return pulumi.get(self, "record_type")

    @property
    @pulumi.getter
    def ttl(self) -> pulumi.Output[int]:
        """
        The record TTL (seconds; minimum `0`; default: `3600`).
        """
        return pulumi.get(self, "ttl")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetComputeInstanceListResult',
    'AwaitableGetComputeInstanceListResult',
    'get_compute_instance_list',
    'get_compute_instance_list_output',
]

@pulumi.output_type
class GetComputeInstanceListResult:
    """
    A collection of values returned by getComputeInstanceList.
    """
    def __init__(__self__, id=None, instances=None, zone=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instances and not isinstance(instances, list):
            raise TypeError("Expected argument 'instances' to be a list")
        pulumi.set(__self__, "instances", instances)
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def instances(self) -> Sequence['outputs.GetComputeInstanceListInstanceResult']:
        return pulumi.get(self, "instances")

    @property
    @pulumi.getter
    def zone(self) -> str:
        return pulumi.get(self, "zone")


class AwaitableGetComputeInstanceListResult(GetComputeInstanceListResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetComputeInstanceListResult(
            id=self.id,
            instances=self.instances,
            zone=self.zone)


def get_compute_instance_list(zone: Optional[str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetComputeInstanceListResult:
    """
    Use this data source to access information about an existing resource.

    :param str zone: The Exoscale [Zone][zone] name.
    """
    __args__ = dict()
    __args__['zone'] = zone
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('exoscale:index/getComputeInstanceList:getComputeInstanceList', __args__, opts=opts, typ=GetComputeInstanceListResult).value

    return AwaitableGetComputeInstanceListResult(
        id=__ret__.id,
        instances=__ret__.instances,
        zone=__ret__.zone)


@_utilities.lift_output_func(get_compute_instance_list)
def get_compute_instance_list_output(zone: Optional[pulumi.Input[str]] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetComputeInstanceListResult]:
    """
    Use this data source to access information about an existing resource.

    :param str zone: The Exoscale [Zone][zone] name.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['IPAddressArgs', 'IPAddress']

@pulumi.input_type
class IPAddressArgs:
    def __init__(__self__, *,
                 zone: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 healthcheck_interval: Optional[pulumi.Input[int]] = None,
                 healthcheck_mode: Optional[pulumi.Input[str]] = None,
                 healthcheck_path: Optional[pulumi.Input[str]] = None,
                 healthcheck_port: Optional[pulumi.Input[int]] = None,
                 healthcheck_strikes_fail: Optional[pulumi.Input[int]] = None,
                 healthcheck_strikes_ok: Optional[pulumi.Input[int]] = None,
                 healthcheck_timeout: Optional[pulumi.Input[int]] = None,
                 healthcheck_tls_skip_verify: Optional[pulumi.Input[bool]] = None,
                 healthcheck_tls_sni: Optional[pulumi.Input[str]] = None,
                 reverse_dns: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a IPAddress resource.
        :param pulumi.Input[str] zone: The Exoscale Zone name
        :param pulumi.Input[str] description: A free-form text describing the Elastic IP (EIP).
        :param pulumi.Input[int] healthcheck_interval: The healthcheck probing interval (seconds; must be between `5` and `300`).
        :param pulumi.Input[str] healthcheck_mode: The healthcheck probing mode (must be `tcp`, `http` or `https`).
        :param pulumi.Input[str] healthcheck_path: The healthcheck probe HTTP request path (must be specified in `http`/`https` modes).
        :param pulumi.Input[int] healthcheck_port: The healthcheck service port to probe (must be between `1` and `65535`).
        :param pulumi.Input[int] healthcheck_strikes_fail: The number of unsuccessful healthcheck probes before considering the target unhealthy (must be between `1` and `20`).
        :param pulumi.Input[int] healthcheck_strikes_ok: The number of successful healthcheck probes before considering the target healthy (must be between `1` and `20`).
        :param pulumi.Input[int] healthcheck_timeout: The time in seconds before considering a healthcheck probing failed (must be between `2` and `60`).
        :param pulumi.Input[bool] healthcheck_tls_skip_verify: Disable TLS certificate validation in `https` mode (boolean; default: `false`). Note: this parameter can only be changed to `true`, it cannot be reset to `false` later on (requires a resource re-creation).
        :param pulumi.Input[str] healthcheck_tls_sni: The healthcheck TLS server name to specify in `https` mode. Note: this parameter can only be changed to a non-empty value, it cannot be reset to its default empty value later on (requires a resource re-creation).
        :param pulumi.Input[str] reverse_dns: The EIP reverse DNS record (must end with a `.`; e.g: `my-eip.example.net.`).
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A dictionary of tags (key/value). To remove all tags, set `tags = {}`.
        """
        pulumi.set(__self__, "zone", zone)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if healthcheck_interval is not None:
            pulumi.set(__self__, "healthcheck_interval", healthcheck_interval)
        if healthcheck_mode is not None:
            pulumi.set(__self__, "healthcheck_mode", healthcheck_mode)
        if healthcheck_path is not None:
            pulumi.set(__self__, "healthcheck_path", healthcheck_path)
        if healthcheck_port is not None:
            pulumi.set(__self__, "healthcheck_port", healthcheck_port)
        if healthcheck_strikes_fail is not None:
            pulumi.set(__self__, "healthcheck_strikes_fail", healthcheck_strikes_fail)
        if healthcheck_strikes_ok is not None:
            pulumi.set(__self__, "healthcheck_strikes_ok", healthcheck_strikes_ok)
        if healthcheck_timeout is not None:
            pulumi.set(__self__, "healthcheck_timeout", healthcheck_timeout)
        if healthcheck_tls_skip_verify is not None:
            pulumi.set(__self__, "healthcheck_tls_skip_verify", healthcheck_tls_skip_verify)
        if healthcheck_tls_sni is not None:
            pulumi.set(__self__, "healthcheck_tls_sni", healthcheck_tls_sni)
        if reverse_dns is not None:
            pulumi.set(__self__, "reverse_dns", reverse_dns)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Input[str]:
        """
        The Exoscale Zone name
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: pulumi.Input[str]):
        pulumi.set(self, "zone", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A free-form text describing the Elastic IP (EIP).
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="healthcheckInterval")
    def healthcheck_interval(self) -> Optional[pulumi.Input[int]]:
        """
        The healthcheck probing interval (seconds; must be between `5` and `300`).
        """
        return pulumi.get(self, "healthcheck_interval")

    @healthcheck_interval.setter
    def healthcheck_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "healthcheck_interval", value)

    @property
    @pulumi.getter(name="healthcheckMode")
    def healthcheck_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The healthcheck probing mode (must be `tcp`, `http` or `https`).
        """
        return pulumi.get(self, "healthcheck_mode")

    @healthcheck_mode.setter
    def healthcheck_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "healthcheck_mode", value)

    @property
    @pulumi.getter(name="healthcheckPath")
    def healthcheck_path(self) -> Optional[pulumi.Input[str]]:
        """
        The healthcheck probe HTTP request path (must be specified in `http`/`https` modes).
        """
        return pulumi.get(self, "healthcheck_path")

    @healthcheck_path.setter
    def healthcheck_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "healthcheck_path", value)

    @property
    @pulumi.getter(name="healthcheckPort")
    def healthcheck_port(self) -> Optional[pulumi.Input[int]]:
        """
        The healthcheck service port to probe (must be between `1` and `65535`).
        """
        return pulumi.get(self, "healthcheck_port")

    @healthcheck_port.setter
    def healthcheck_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "healthcheck_port", value)

    @property
    @pulumi.getter(name="healthcheckStrikesFail")
    def healthcheck_strikes_fail(self) -> Optional[pulumi.Input[int]]:
        """
        The number of unsuccessful healthcheck probes before considering the target unhealthy (must be between `1` and `20`).
        """
        return pulumi.get(self, "healthcheck_strikes_fail")

    @healthcheck_strikes_fail.setter
    def healthcheck_strikes_fail(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "healthcheck_strikes_fail", value)

    @property
    @pulumi.getter(name="healthcheckStrikesOk")
    def healthcheck_strikes_ok(self) -> Optional[pulumi.Input[int]]:
        """
        The number of successful healthcheck probes before considering the target healthy (must be between `1` and `20`).
        """
        return pulumi.get(self, "healthcheck_strikes_ok")

    @healthcheck_strikes_ok.setter
    def healthcheck_strikes_ok(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "healthcheck_strikes_ok", value)

    @property
    @pulumi.getter(name="healthcheckTimeout")
    def healthcheck_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        The time in seconds before considering a healthcheck probing failed (must be between `2` and `60`).
        """
        return pulumi.get(self, "healthcheck_timeout")

    @healthcheck_timeout.setter
    def healthcheck_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "healthcheck_timeout", value)

    @property
    @pulumi.getter(name="healthcheckTlsSkipVerify")
    def healthcheck_tls_skip_verify(self) -> Optional[pulumi.Input[bool]]:
        """
        Disable TLS certificate validation in `https` mode (boolean; default: `false`). Note: this parameter can only be changed to `true`, it cannot be reset to `false` later on (requires a resource re-creation).
        """
        return pulumi.get(self, "healthcheck_tls_skip_verify")

    @healthcheck_tls_skip_verify.setter
    def healthcheck_tls_skip_verify(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "healthcheck_tls_skip_verify", value)

    @property
    @pulumi.getter(name="healthcheckTlsSni")
    def healthcheck_tls_sni(self) -> Optional[pulumi.Input[str]]:
        """
        The healthcheck TLS server name to specify in `https` mode. Note: this parameter can only be changed to a non-empty value, it cannot be reset to its default empty value later on (requires a resource re-creation).
        """
        return pulumi.get(self, "healthcheck_tls_sni")

    @healthcheck_tls_sni.setter
    def healthcheck_tls_sni(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "healthcheck_tls_sni", value)

    @property
    @pulumi.getter(name="reverseDns")
    def reverse_dns(self) -> Optional[pulumi.Input[str]]:
        """
        The EIP reverse DNS record (must end with a `.`; e.g: `my-eip.example.net.`).
        """
        return pulumi.get(self, "reverse_dns")

    @reverse_dns.setter
    def reverse_dns(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "reverse_dns", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A dictionary of tags (key/value). To remove all tags, set `tags = {}`.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _IPAddressState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 healthcheck_interval: Optional[pulumi.Input[int]] = None,
                 healthcheck_mode: Optional[pulumi.Input[str]] = None,
                 healthcheck_path: Optional[pulumi.Input[str]] = None,
                 healthcheck_port: Optional[pulumi.Input[int]] = None,
                 healthcheck_strikes_fail: Optional[pulumi.Input[int]] = None,
                 healthcheck_strikes_ok: Optional[pulumi.Input[int]] = None,
                 healthcheck_timeout: Optional[pulumi.Input[int]] = None,
                 healthcheck_tls_skip_verify: Optional[pulumi.Input[bool]] = None,
                 healthcheck_tls_sni: Optional[pulumi.Input[str]] = None,
                 ip_address: Optional[pulumi.Input[str]] = None,
                 reverse_dns: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 zone: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering IPAddress resources.
        :param pulumi.Input[str] description: A free-form text describing the Elastic IP (EIP).
        :param pulumi.Input[int] healthcheck_interval: The healthcheck probing interval (seconds; must be between `5` and `300`).
        :param pulumi.Input[str] healthcheck_mode: The healthcheck probing mode (must be `tcp`, `http` or `https`).
        :param pulumi.Input[str] healthcheck_path: The healthcheck probe HTTP request path (must be specified in `http`/`https` modes).
        :param pulumi.Input[int] healthcheck_port: The healthcheck service port to probe (must be between `1` and `65535`).
        :param pulumi.Input[int] healthcheck_strikes_fail: The number of unsuccessful healthcheck probes before considering the target unhealthy (must be between `1` and `20`).
        :param pulumi.Input[int] healthcheck_strikes_ok: The number of successful healthcheck probes before considering the target healthy (must be between `1` and `20`).
        :param pulumi.Input[int] healthcheck_timeout: The time in seconds before considering a healthcheck probing failed (must be between `2` and `60`).
        :param pulumi.Input[bool] healthcheck_tls_skip_verify: Disable TLS certificate validation in `https` mode (boolean; default: `false`). Note: this parameter can only be changed to `true`, it cannot be reset to `false` later on (requires a resource re-creation).
        :param pulumi.Input[str] healthcheck_tls_sni: The healthcheck TLS server name to specify in `https` mode. Note: this parameter can only be changed to a non-empty value, it cannot be reset to its default empty value later on (requires a resource re-creation).
        :param pulumi.Input[str] ip_address: The Elastic IP (EIP) IPv4 address.
        :param pulumi.Input[str] reverse_dns: The EIP reverse DNS record (must end with a `.`; e.g: `my-eip.example.net.`).
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A dictionary of tags (key/value). To remove all tags, set `tags = {}`.
        :param pulumi.Input[str] zone: The Exoscale Zone name
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if healthcheck_interval is not None:
            pulumi.set(__self__, "healthcheck_interval", healthcheck_interval)
        if healthcheck_mode is not None:
            pulumi.set(__self__, "healthcheck_mode", healthcheck_mode)
        if healthcheck_path is not None:
            pulumi.set(__self__, "healthcheck_path", healthcheck_path)
        if healthcheck_port is not None:
            pulumi.set(__self__, "healthcheck_port", healthcheck_port)
        if healthcheck_strikes_fail is not None:
            pulumi.set(__self__, "healthcheck_strikes_fail", healthcheck_strikes_fail)
        if healthcheck_strikes_ok is not None:
            pulumi.set(__self__, "healthcheck_strikes_ok", healthcheck_strikes_ok)
        if healthcheck_timeout is not None:
            pulumi.set(__self__, "healthcheck_timeout", healthcheck_timeout)
        if healthcheck_tls_skip_verify is not None:
            pulumi.set(__self__, "healthcheck_tls_skip_verify", healthcheck_tls_skip_verify)
        if healthcheck_tls_sni is not None:
            pulumi.set(__self__, "healthcheck_tls_sni", healthcheck_tls_sni)
        if ip_address is not None:
            pulumi.set(__self__, "ip_address", ip_address)
        if reverse_dns is not None:
            pulumi.set(__self__, "reverse_dns", reverse_dns)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A free-form text describing the Elastic IP (EIP).
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="healthcheckInterval")
    def healthcheck_interval(self) -> Optional[pulumi.Input[int]]:
        """
        The healthcheck probing interval (seconds; must be between `5` and `300`).
        """
        return pulumi.get(self, "healthcheck_interval")

    @healthcheck_interval.setter
    def healthcheck_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "healthcheck_interval", value)

    @property
    @pulumi.getter(name="healthcheckMode")
    def healthcheck_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The healthcheck probing mode (must be `tcp`, `http` or `https`).
        """
        return pulumi.get(self, "healthcheck_mode")

    @healthcheck_mode.setter
    def healthcheck_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "healthcheck_mode", value)

    @property
    @pulumi.getter(name="healthcheckPath")
    def healthcheck_path(self) -> Optional[pulumi.Input[str]]:
        """
        The healthcheck probe HTTP request path (must be specified in `http`/`https` modes).
        """
        return pulumi.get(self, "healthcheck_path")

    @healthcheck_path.setter
    def healthcheck_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "healthcheck_path", value)

    @property
    @pulumi.getter(name="healthcheckPort")
    def healthcheck_port(self) -> Optional[pulumi.Input[int]]:
        """
        The healthcheck service port to probe (must be between `1` and `65535`).
        """
        return pulumi.get(self, "healthcheck_port")

    @healthcheck_port.setter
    def healthcheck_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "healthcheck_port", value)

    @property
    @pulumi.getter(name="healthcheckStrikesFail")
    def healthcheck_strikes_fail(self) -> Optional[pulumi.Input[int]]:
        """
        The number of unsuccessful healthcheck probes before considering the target unhealthy (must be between `1` and `20`).
        """
        return pulumi.get(self, "healthcheck_strikes_fail")

    @healthcheck_strikes_fail.setter
    def healthcheck_strikes_fail(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "healthcheck_strikes_fail", value)

    @property
    @pulumi.getter(name="healthcheckStrikesOk")
    def healthcheck_strikes_ok(self) -> Optional[pulumi.Input[int]]:
        """
        The number of successful healthcheck probes before considering the target healthy (must be between `1` and `20`).
        """
        return pulumi.get(self, "healthcheck_strikes_ok")

    @healthcheck_strikes_ok.setter
    def healthcheck_strikes_ok(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "healthcheck_strikes_ok", value)

    @property
    @pulumi.getter(name="healthcheckTimeout")
    def healthcheck_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        The time in seconds before considering a healthcheck probing failed (must be between `2` and `60`).
        """
        return pulumi.get(self, "healthcheck_timeout")

    @healthcheck_timeout.setter
    def healthcheck_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "healthcheck_timeout", value)

    @property
    @pulumi.getter(name="healthcheckTlsSkipVerify")
    def healthcheck_tls_skip_verify(self) -> Optional[pulumi.Input[bool]]:
        """
        Disable TLS certificate validation in `https` mode (boolean; default: `false`). Note: this parameter can only be changed to `true`, it cannot be reset to `false` later on (requires a resource re-creation).
        """
        return pulumi.get(self, "healthcheck_tls_skip_verify")

    @healthcheck_tls_skip_verify.setter
    def healthcheck_tls_skip_verify(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "healthcheck_tls_skip_verify", value)

    @property
    @pulumi.getter(name="healthcheckTlsSni")
    def healthcheck_tls_sni(self) -> Optional[pulumi.Input[str]]:
        """
        The healthcheck TLS server name to specify in `https` mode. Note: this parameter can only be changed to a non-empty value, it cannot be reset to its default empty value later on (requires a resource re-creation).
        """
        return pulumi.get(self, "healthcheck_tls_sni")

    @healthcheck_tls_sni.setter
    def healthcheck_tls_sni(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "healthcheck_tls_sni", value)

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> Optional[pulumi.Input[str]]:
        """
        The Elastic IP (EIP) IPv4 address.
        """
        return pulumi.get(self, "ip_address")

    @ip_address.setter
    def ip_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip_address", value)

    @property
    @pulumi.getter(name="reverseDns")
    def reverse_dns(self) -> Optional[pulumi.Input[str]]:
        """
        The EIP reverse DNS record (must end with a `.`; e.g: `my-eip.example.net.`).
        """
        return pulumi.get(self, "reverse_dns")

    @reverse_dns.setter
    def reverse_dns(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "reverse_dns", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A dictionary of tags (key/value). To remove all tags, set `tags = {}`.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[str]]:
        """
        The Exoscale Zone name
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "zone", value)


class IPAddress(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 healthcheck_interval: Optional[pulumi.Input[int]] = None,
                 healthcheck_mode: Optional[pulumi.Input[str]] = None,
                 healthcheck_path: Optional[pulumi.Input[str]] = None,
                 healthcheck_port: Optional[pulumi.Input[int]] = None,
                 healthcheck_strikes_fail: Optional[pulumi.Input[int]] = None,
                 healthcheck_strikes_ok: Optional[pulumi.Input[int]] = None,
                 healthcheck_timeout: Optional[pulumi.Input[int]] = None,
                 healthcheck_tls_skip_verify: Optional[pulumi.Input[bool]] = None,
                 healthcheck_tls_sni: Optional[pulumi.Input[str]] = None,
                 reverse_dns: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 zone: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        !> **WARNING:** This resource is **DEPRECATED** and will be removed in the next major version. Please use ElasticIP instead.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: A free-form text describing the Elastic IP (EIP).
        :param pulumi.Input[int] healthcheck_interval: The healthcheck probing interval (seconds; must be between `5` and `300`).
        :param pulumi.Input[str] healthcheck_mode: The healthcheck probing mode (must be `tcp`, `http` or `https`).
        :param pulumi.Input[str] healthcheck_path: The healthcheck probe HTTP request path (must be specified in `http`/`https` modes).
        :param pulumi.Input[int] healthcheck_port: The healthcheck service port to probe (must be between `1` and `65535`).
        :param pulumi.Input[int] healthcheck_strikes_fail: The number of unsuccessful healthcheck probes before considering the target unhealthy (must be between `1` and `20`).
        :param pulumi.Input[int] healthcheck_strikes_ok: The number of successful healthcheck probes before considering the target healthy (must be between `1` and `20`).
        :param pulumi.Input[int] healthcheck_timeout: The time in seconds before considering a healthcheck probing failed (must be between `2` and `60`).
        :param pulumi.Input[bool] healthcheck_tls_skip_verify: Disable TLS certificate validation in `https` mode (boolean; default: `false`). Note: this parameter can only be changed to `true`, it cannot be reset to `false` later on (requires a resource re-creation).
        :param pulumi.Input[str] healthcheck_tls_sni: The healthcheck TLS server name to specify in `https` mode. Note: this parameter can only be changed to a non-empty value, it cannot be reset to its default empty value later on (requires a resource re-creation).
        :param pulumi.Input[str] reverse_dns: The EIP reverse DNS record (must end with a `.`; e.g: `my-eip.example.net.`).
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A dictionary of tags (key/value). To remove all tags, set `tags = {}`.
        :param pulumi.Input[str] zone: The Exoscale Zone name
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IPAddressArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        !> **WARNING:** This resource is **DEPRECATED** and will be removed in the next major version. Please use ElasticIP instead.

        :param str resource_name: The name of the resource.
        :param IPAddressArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IPAddressArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 healthcheck_interval: Optional[pulumi.Input[int]] = None,
                 healthcheck_mode: Optional[pulumi.Input[str]] = None,
                 healthcheck_path: Optional[pulumi.Input[str]] = None,
                 healthcheck_port: Optional[pulumi.Input[int]] = None,
                 healthcheck_strikes_fail: Optional[pulumi.Input[int]] = None,
                 healthcheck_strikes_ok: Optional[pulumi.Input[int]] = None,
                 healthcheck_timeout: Optional[pulumi.Input[int]] = None,
                 healthcheck_tls_skip_verify: Optional[pulumi.Input[bool]] = None,
                 healthcheck_tls_sni: Optional[pulumi.Input[str]] = None,
                 reverse_dns: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 zone: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IPAddressArgs.__new__(IPAddressArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["healthcheck_interval"] = healthcheck_interval
            __props__.__dict__["healthcheck_mode"] = healthcheck_mode
            __props__.__dict__["healthcheck_path"] = healthcheck_path
            __props__.__dict__["healthcheck_port"] = healthcheck_port
            __props__.__dict__["healthcheck_strikes_fail"] = healthcheck_strikes_fail
            __props__.__dict__["healthcheck_strikes_ok"] = healthcheck_strikes_ok
            __props__.__dict__["healthcheck_timeout"] = healthcheck_timeout
            __props__.__dict__["healthcheck_tls_skip_verify"] = healthcheck_tls_skip_verify
            __props__.__dict__["healthcheck_tls_sni"] = healthcheck_tls_sni
            __props__.__dict__["reverse_dns"] = reverse_dns
            __props__.__dict__["tags"] = tags
            if zone is None and not opts.urn:
                raise TypeError("Missing required property 'zone'")
            __props__.__dict__["zone"] = zone
            __props__.__dict__["ip_address"] = None
        super(IPAddress, __self__).__init__(
            'exoscale:index/iPAddress:IPAddress',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            healthcheck_interval: Optional[pulumi.Input[int]] = None,
            healthcheck_mode: Optional[pulumi.Input[str]] = None,
            healthcheck_path: Optional[pulumi.Input[str]] = None,
            healthcheck_port: Optional[pulumi.Input[int]] = None,
            healthcheck_strikes_fail: Optional[pulumi.Input[int]] = None,
            healthcheck_strikes_ok: Optional[pulumi.Input[int]] = None,
            healthcheck_timeout: Optional[pulumi.Input[int]] = None,
            healthcheck_tls_skip_verify: Optional[pulumi.Input[bool]] = None,
            healthcheck_tls_sni: Optional[pulumi.Input[str]] = None,
            ip_address: Optional[pulumi.Input[str]] = None,
            reverse_dns: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            zone: Optional[pulumi.Input[str]] = None) -> 'IPAddress':
        """
        Get an existing IPAddress resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: A free-form text describing the Elastic IP (EIP).
        :param pulumi.Input[int] healthcheck_interval: The healthcheck probing interval (seconds; must be between `5` and `300`).
        :param pulumi.Input[str] healthcheck_mode: The healthcheck probing mode (must be `tcp`, `http` or `https`).
        :param pulumi.Input[str] healthcheck_path: The healthcheck probe HTTP request path (must be specified in `http`/`https` modes).
        :param pulumi.Input[int] healthcheck_port: The healthcheck service port to probe (must be between `1` and `65535`).
        :param pulumi.Input[int] healthcheck_strikes_fail: The number of unsuccessful healthcheck probes before considering the target unhealthy (must be between `1` and `20`).
        :param pulumi.Input[int] healthcheck_strikes_ok: The number of successful healthcheck probes before considering the target healthy (must be between `1` and `20`).
        :param pulumi.Input[int] healthcheck_timeout: The time in seconds before considering a healthcheck probing failed (must be between `2` and `60`).
        :param pulumi.Input[bool] healthcheck_tls_skip_verify: Disable TLS certificate validation in `https` mode (boolean; default: `false`). Note: this parameter can only be changed to `true`, it cannot be reset to `false` later on (requires a resource re-creation).
        :param pulumi.Input[str] healthcheck_tls_sni: The healthcheck TLS server name to specify in `https` mode. Note: this parameter can only be changed to a non-empty value, it cannot be reset to its default empty value later on (requires a resource re-creation).
        :param pulumi.Input[str] ip_address: The Elastic IP (EIP) IPv4 address.
        :param pulumi.Input[str] reverse_dns: The EIP reverse DNS record (must end with a `.`; e.g: `my-eip.example.net.`).
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A dictionary of tags (key/value). To remove all tags, set `tags = {}`.
        :param pulumi.Input[str] zone: The Exoscale Zone name
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IPAddressState.__new__(_IPAddressState)

        __props__.__dict__["description"] = description
        __props__.__dict__["healthcheck_interval"] = healthcheck_interval
        __props__.__dict__["healthcheck_mode"] = healthcheck_mode
        __props__.__dict__["healthcheck_path"] = healthcheck_path
        __props__.__dict__["healthcheck_port"] = healthcheck_port
        __props__.__dict__["healthcheck_strikes_fail"] = healthcheck_strikes_fail
        __props__.__dict__["healthcheck_strikes_ok"] = healthcheck_strikes_ok
        __props__.__dict__["healthcheck_timeout"] = healthcheck_timeout
        __props__.__dict__["healthcheck_tls_skip_verify"] = healthcheck_tls_skip_verify
        __props__.__dict__["healthcheck_tls_sni"] = healthcheck_tls_sni
        __props__.__dict__["ip_address"] = ip_address
        __props__.__dict__["reverse_dns"] = reverse_dns
        __props__.__dict__["tags"] = tags
        __props__.__dict__["zone"] = zone
        return IPAddress(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        A free-form text describing the Elastic IP (EIP).
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="healthcheckInterval")
    def healthcheck_interval(self) -> pulumi.Output[Optional[int]]:
        """
        The healthcheck probing interval (seconds; must be between `5` and `300`).
        """
        return pulumi.get(self, "healthcheck_interval")

    @property
    @pulumi.getter(name="healthcheckMode")
    def healthcheck_mode(self) -> pulumi.Output[Optional[str]]:
        """
        The healthcheck probing mode (must be `tcp`, `http` or `https`).
        """
        return pulumi.get(self, "healthcheck_mode")

    @property
    @pulumi.getter(name="healthcheckPath")
    def healthcheck_path(self) -> pulumi.Output[Optional[str]]:
        """
        The healthcheck probe HTTP request path (must be specified in `http`/`https` modes).
        """
        return pulumi.get(self, "healthcheck_path")

    @property
    @pulumi.getter(name="healthcheckPort")
    def healthcheck_port(self) -> pulumi.Output[Optional[int]]:
        """
        The healthcheck service port to probe (must be between `1` and `65535`).
        """
        return pulumi.get(self, "healthcheck_port")

    @property
    @pulumi.getter(name="healthcheckStrikesFail")
    def healthcheck_strikes_fail(self) -> pulumi.Output[Optional[int]]:
        """
        The number of unsuccessful healthcheck probes before considering the target unhealthy (must be between `1` and `20`).
        """
        return pulumi.get(self, "healthcheck_strikes_fail")

    @property
    @pulumi.getter(name="healthcheckStrikesOk")
    def healthcheck_strikes_ok(self) -> pulumi.Output[Optional[int]]:
        """
        The number of successful healthcheck probes before considering the target healthy (must be between `1` and `20`).
        """
        return pulumi.get(self, "healthcheck_strikes_ok")

    @property
    @pulumi.getter(name="healthcheckTimeout")
    def healthcheck_timeout(self) -> pulumi.Output[Optional[int]]:
        """
        The time in seconds before considering a healthcheck probing failed (must be between `2` and `60`).
        """
        return pulumi.get(self, "healthcheck_timeout")

    @property
    @pulumi.getter(name="healthcheckTlsSkipVerify")
    def healthcheck_tls_skip_verify(self) -> pulumi.Output[Optional[bool]]:
        """
        Disable TLS certificate validation in `https` mode (boolean; default: `false`). Note: this parameter can only be changed to `true`, it cannot be reset to `false` later on (requires a resource re-creation).
        """
        return pulumi.get(self, "healthcheck_tls_skip_verify")

    @property
    @pulumi.getter(name="healthcheckTlsSni")
    def healthcheck_tls_sni(self) -> pulumi.Output[Optional[str]]:
        """
        The healthcheck TLS server name to specify in `https` mode. Note: this parameter can only be changed to a non-empty value, it cannot be reset to its default empty value later on (requires a resource re-creation).
        """
        return pulumi.get(self, "healthcheck_tls_sni")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> pulumi.Output[str]:
        """
        The Elastic IP (EIP) IPv4 address.
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="reverseDns")
    def reverse_dns(self) -> pulumi.Output[Optional[str]]:
        """
        The EIP reverse DNS record (must end with a `.`; e.g: `my-eip.example.net.`).
        """
        return pulumi.get(self, "reverse_dns")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Mapping[str, str]]:
        """
        A dictionary of tags (key/value). To remove all tags, set `tags = {}`.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Output[str]:
        """
        The Exoscale Zone name
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SecurityGroupRulesArgs', 'SecurityGroupRules']

@pulumi.input_type
class SecurityGroupRulesArgs:
    def __init__(__self__, *,
                 egresses: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupRulesEgressArgs']]]] = None,
                 ingresses: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupRulesIngressArgs']]]] = None,
                 security_group: Optional[pulumi.Input[str]] = None,
                 security_group_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a SecurityGroupRules resource.
        :param pulumi.Input[str] security_group: The security group (name) the rules apply to (conflicts with `security_group_id`).
        :param pulumi.Input[str] security_group_id: The security group (ID) the rules apply to (conficts with `security_group)`.
        """
        if egresses is not None:
            pulumi.set(__self__, "egresses", egresses)
        if ingresses is not None:
            pulumi.set(__self__, "ingresses", ingresses)
        if security_group is not None:
            pulumi.set(__self__, "security_group", security_group)
        if security_group_id is not None:
            pulumi.set(__self__, "security_group_id", security_group_id)

    @property
    @pulumi.getter
    def egresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupRulesEgressArgs']]]]:
        return pulumi.get(self, "egresses")

    @egresses.setter
    def egresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupRulesEgressArgs']]]]):
        pulumi.set(self, "egresses", value)

    @property
    @pulumi.getter
    def ingresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupRulesIngressArgs']]]]:
        return pulumi.get(self, "ingresses")

    @ingresses.setter
    def ingresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupRulesIngressArgs']]]]):
        pulumi.set(self, "ingresses", value)

    @property
    @pulumi.getter(name="securityGroup")
    def security_group(self) -> Optional[pulumi.Input[str]]:
        """
        The security group (name) the rules apply to (conflicts with `security_group_id`).
        """
        return pulumi.get(self, "security_group")

    @security_group.setter
    def security_group(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security_group", value)

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The security group (ID) the rules apply to (conficts with `security_group)`.
        """
        return pulumi.get(self, "security_group_id")

    @security_group_id.setter
    def security_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security_group_id", value)


@pulumi.input_type
class _SecurityGroupRulesState:
    def __init__(__self__, *,
                 egresses: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupRulesEgressArgs']]]] = None,
                 ingresses: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupRulesIngressArgs']]]] = None,
                 security_group: Optional[pulumi.Input[str]] = None,
                 security_group_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering SecurityGroupRules resources.
        :param pulumi.Input[str] security_group: The security group (name) the rules apply to (conflicts with `security_group_id`).
        :param pulumi.Input[str] security_group_id: The security group (ID) the rules apply to (conficts with `security_group)`.
        """
        if egresses is not None:
            pulumi.set(__self__, "egresses", egresses)
        if ingresses is not None:
            pulumi.set(__self__, "ingresses", ingresses)
        if security_group is not None:
            pulumi.set(__self__, "security_group", security_group)
        if security_group_id is not None:
            pulumi.set(__self__, "security_group_id", security_group_id)

    @property
    @pulumi.getter
    def egresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupRulesEgressArgs']]]]:
        return pulumi.get(self, "egresses")

    @egresses.setter
    def egresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupRulesEgressArgs']]]]):
        pulumi.set(self, "egresses", value)

    @property
    @pulumi.getter
    def ingresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupRulesIngressArgs']]]]:
        return pulumi.get(self, "ingresses")

    @ingresses.setter
    def ingresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGroupRulesIngressArgs']]]]):
        pulumi.set(self, "ingresses", value)

    @property
    @pulumi.getter(name="securityGroup")
    def security_group(self) -> Optional[pulumi.Input[str]]:
        """
        The security group (name) the rules apply to (conflicts with `security_group_id`).
        """
        return pulumi.get(self, "security_group")

    @security_group.setter
    def security_group(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security_group", value)

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The security group (ID) the rules apply to (conficts with `security_group)`.
        """
        return pulumi.get(self, "security_group_id")

    @security_group_id.setter
    def security_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security_group_id", value)


class SecurityGroupRules(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 egresses: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SecurityGroupRulesEgressArgs']]]]] = None,
                 ingresses: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SecurityGroupRulesIngressArgs']]]]] = None,
                 security_group: Optional[pulumi.Input[str]] = None,
                 security_group_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        !> **WARNING:** This resource is **DEPRECATED** and will be removed in the next major version. Please use the SecurityGroupRule instead (or refer to the ad-hoc migration guide).

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] security_group: The security group (name) the rules apply to (conflicts with `security_group_id`).
        :param pulumi.Input[str] security_group_id: The security group (ID) the rules apply to (conficts with `security_group)`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[SecurityGroupRulesArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        !> **WARNING:** This resource is **DEPRECATED** and will be removed in the next major version. Please use the SecurityGroupRule instead (or refer to the ad-hoc migration guide).

        :param str resource_name: The name of the resource.
        :param SecurityGroupRulesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecurityGroupRulesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 egresses: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SecurityGroupRulesEgressArgs']]]]] = None,
                 ingresses: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SecurityGroupRulesIngressArgs']]]]] = None,
                 security_group: Optional[pulumi.Input[str]] = None,
                 security_group_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecurityGroupRulesArgs.__new__(SecurityGroupRulesArgs)

            __props__.__dict__["egresses"] = egresses
            __props__.__dict__["ingresses"] = ingresses
            __props__.__dict__["security_group"] = security_group
            __props__.__dict__["security_group_id"] = security_group_id
        super(SecurityGroupRules, __self__).__init__(
            'exoscale:index/securityGroupRules:SecurityGroupRules',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            egresses: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SecurityGroupRulesEgressArgs']]]]] = None,
            ingresses: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['SecurityGroupRulesIngressArgs']]]]] = None,
            security_group: Optional[pulumi.Input[str]] = None,
            security_group_id: Optional[pulumi.Input[str]] = None) -> 'SecurityGroupRules':
        """
        Get an existing SecurityGroupRules resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] security_group: The security group (name) the rules apply to (conflicts with `security_group_id`).
        :param pulumi.Input[str] security_group_id: The security group (ID) the rules apply to (conficts with `security_group)`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecurityGroupRulesState.__new__(_SecurityGroupRulesState)

        __props__.__dict__["egresses"] = egresses
        __props__.__dict__["ingresses"] = ingresses
        __props__.__dict__["security_group"] = security_group
        __props__.__dict__["security_group_id"] = security_group_id
        return SecurityGroupRules(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def egresses(self) -> pulumi.Output[Optional[Sequence['outputs.SecurityGroupRulesEgress']]]:
        return pulumi.get(self, "egresses")

    @property
    @pulumi.getter
    def ingresses(self) -> pulumi.Output[Optional[Sequence['outputs.SecurityGroupRulesIngress']]]:
        return pulumi.get(self, "ingresses")

    @property
    @pulumi.getter(name="securityGroup")
    def security_group(self) -> pulumi.Output[str]:
        """
        The security group (name) the rules apply to (conflicts with `security_group_id`).
        """
        return pulumi.get(self, "security_group")

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> pulumi.Output[str]:
        """
        The security group (ID) the rules apply to (conficts with `security_group)`.
        """
        return pulumi.get(self, "security_group_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

import types

__config__ = pulumi.Config('exoscale')


class _ExportableConfig(types.ModuleType):
    @property
    def compute_endpoint(self) -> Optional[str]:
        """
        Exoscale CloudStack API endpoint (by default: https://api.exoscale.com/v1)
        """
        return __config__.get('computeEndpoint')

    @property
    def config(self) -> Optional[str]:
        """
        CloudStack ini configuration filename (by default: cloudstack.ini)
        """
        return __config__.get('config')

    @property
    def delay(self) -> Optional[int]:
        return __config__.get_int('delay')

    @property
    def dns_endpoint(self) -> Optional[str]:
        """
        Exoscale DNS API endpoint (by default: https://api.exoscale.com/dns)
        """
        return __config__.get('dnsEndpoint')

    @property
    def environment(self) -> Optional[str]:
        return __config__.get('environment')

    @property
    def gzip_user_data(self) -> Optional[bool]:
        """
        Defines if the user-data of compute instances should be gzipped (by default: true)
        """
        return __config__.get_bool('gzipUserData')

    @property
    def key(self) -> Optional[str]:
        """
        Exoscale API key
        """
        return __config__.get('key')

    @property
    def profile(self) -> Optional[str]:
        return __config__.get('profile')

    @property
    def region(self) -> Optional[str]:
        """
        CloudStack ini configuration section name (by default: cloudstack)
        """
        return __config__.get('region')

    @property
    def secret(self) -> Optional[str]:
        """
        Exoscale API secret
        """
        return __config__.get('secret')

    @property
    def timeout(self) -> Optional[int]:
        """
        Timeout in seconds for waiting on compute resources to become available (by default: 300)
        """
        return __config__.get_int('timeout')

    @property
    def token(self) -> Optional[str]:
        return __config__.get('token')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DatabaseArgs', 'Database']

@pulumi.input_type
class DatabaseArgs:
    def __init__(__self__, *,
                 plan: pulumi.Input[str],
                 type: pulumi.Input[str],
                 zone: pulumi.Input[str],
                 kafka: Optional[pulumi.Input['DatabaseKafkaArgs']] = None,
                 maintenance_dow: Optional[pulumi.Input[str]] = None,
                 maintenance_time: Optional[pulumi.Input[str]] = None,
                 mysql: Optional[pulumi.Input['DatabaseMysqlArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 opensearch: Optional[pulumi.Input['DatabaseOpensearchArgs']] = None,
                 pg: Optional[pulumi.Input['DatabasePgArgs']] = None,
                 redis: Optional[pulumi.Input['DatabaseRedisArgs']] = None,
                 termination_protection: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a Database resource.
        :param pulumi.Input[str] plan: The plan of the database service (use the [Exoscale CLI][cli] - `exo dbaas type show <TYPE>` - for reference).
        :param pulumi.Input[str] type: The type of the database service (`kafka`, `mysql`, `opensearch`, `pg`, `redis`).
        :param pulumi.Input[str] zone: The Exoscale [Zone][zone] name.
        :param pulumi.Input['DatabaseKafkaArgs'] kafka: *kafka* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[str] maintenance_dow: The day of week to perform the automated database service maintenance (`never`, `monday`, `tuesday`, `wednesday`, `thursday`, `friday`, `saturday`, `sunday`).
        :param pulumi.Input[str] maintenance_time: The time of day to perform the automated database service maintenance (`HH:MM:SS`)
        :param pulumi.Input['DatabaseMysqlArgs'] mysql: *mysql* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[str] name: The name of the database service.
        :param pulumi.Input['DatabaseOpensearchArgs'] opensearch: *opensearch* database service type specific arguments. Structure is documented below.
        :param pulumi.Input['DatabasePgArgs'] pg: *pg* database service type specific arguments. Structure is documented below.
        :param pulumi.Input['DatabaseRedisArgs'] redis: *redis* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[bool] termination_protection: The database service protection boolean flag against termination/power-off.
        """
        pulumi.set(__self__, "plan", plan)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "zone", zone)
        if kafka is not None:
            pulumi.set(__self__, "kafka", kafka)
        if maintenance_dow is not None:
            pulumi.set(__self__, "maintenance_dow", maintenance_dow)
        if maintenance_time is not None:
            pulumi.set(__self__, "maintenance_time", maintenance_time)
        if mysql is not None:
            pulumi.set(__self__, "mysql", mysql)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if opensearch is not None:
            pulumi.set(__self__, "opensearch", opensearch)
        if pg is not None:
            pulumi.set(__self__, "pg", pg)
        if redis is not None:
            pulumi.set(__self__, "redis", redis)
        if termination_protection is not None:
            pulumi.set(__self__, "termination_protection", termination_protection)

    @property
    @pulumi.getter
    def plan(self) -> pulumi.Input[str]:
        """
        The plan of the database service (use the [Exoscale CLI][cli] - `exo dbaas type show <TYPE>` - for reference).
        """
        return pulumi.get(self, "plan")

    @plan.setter
    def plan(self, value: pulumi.Input[str]):
        pulumi.set(self, "plan", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        The type of the database service (`kafka`, `mysql`, `opensearch`, `pg`, `redis`).
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Input[str]:
        """
        The Exoscale [Zone][zone] name.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: pulumi.Input[str]):
        pulumi.set(self, "zone", value)

    @property
    @pulumi.getter
    def kafka(self) -> Optional[pulumi.Input['DatabaseKafkaArgs']]:
        """
        *kafka* database service type specific arguments. Structure is documented below.
        """
        return pulumi.get(self, "kafka")

    @kafka.setter
    def kafka(self, value: Optional[pulumi.Input['DatabaseKafkaArgs']]):
        pulumi.set(self, "kafka", value)

    @property
    @pulumi.getter(name="maintenanceDow")
    def maintenance_dow(self) -> Optional[pulumi.Input[str]]:
        """
        The day of week to perform the automated database service maintenance (`never`, `monday`, `tuesday`, `wednesday`, `thursday`, `friday`, `saturday`, `sunday`).
        """
        return pulumi.get(self, "maintenance_dow")

    @maintenance_dow.setter
    def maintenance_dow(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "maintenance_dow", value)

    @property
    @pulumi.getter(name="maintenanceTime")
    def maintenance_time(self) -> Optional[pulumi.Input[str]]:
        """
        The time of day to perform the automated database service maintenance (`HH:MM:SS`)
        """
        return pulumi.get(self, "maintenance_time")

    @maintenance_time.setter
    def maintenance_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "maintenance_time", value)

    @property
    @pulumi.getter
    def mysql(self) -> Optional[pulumi.Input['DatabaseMysqlArgs']]:
        """
        *mysql* database service type specific arguments. Structure is documented below.
        """
        return pulumi.get(self, "mysql")

    @mysql.setter
    def mysql(self, value: Optional[pulumi.Input['DatabaseMysqlArgs']]):
        pulumi.set(self, "mysql", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the database service.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def opensearch(self) -> Optional[pulumi.Input['DatabaseOpensearchArgs']]:
        """
        *opensearch* database service type specific arguments. Structure is documented below.
        """
        return pulumi.get(self, "opensearch")

    @opensearch.setter
    def opensearch(self, value: Optional[pulumi.Input['DatabaseOpensearchArgs']]):
        pulumi.set(self, "opensearch", value)

    @property
    @pulumi.getter
    def pg(self) -> Optional[pulumi.Input['DatabasePgArgs']]:
        """
        *pg* database service type specific arguments. Structure is documented below.
        """
        return pulumi.get(self, "pg")

    @pg.setter
    def pg(self, value: Optional[pulumi.Input['DatabasePgArgs']]):
        pulumi.set(self, "pg", value)

    @property
    @pulumi.getter
    def redis(self) -> Optional[pulumi.Input['DatabaseRedisArgs']]:
        """
        *redis* database service type specific arguments. Structure is documented below.
        """
        return pulumi.get(self, "redis")

    @redis.setter
    def redis(self, value: Optional[pulumi.Input['DatabaseRedisArgs']]):
        pulumi.set(self, "redis", value)

    @property
    @pulumi.getter(name="terminationProtection")
    def termination_protection(self) -> Optional[pulumi.Input[bool]]:
        """
        The database service protection boolean flag against termination/power-off.
        """
        return pulumi.get(self, "termination_protection")

    @termination_protection.setter
    def termination_protection(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "termination_protection", value)


@pulumi.input_type
class _DatabaseState:
    def __init__(__self__, *,
                 ca_certificate: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 disk_size: Optional[pulumi.Input[int]] = None,
                 kafka: Optional[pulumi.Input['DatabaseKafkaArgs']] = None,
                 maintenance_dow: Optional[pulumi.Input[str]] = None,
                 maintenance_time: Optional[pulumi.Input[str]] = None,
                 mysql: Optional[pulumi.Input['DatabaseMysqlArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 node_cpus: Optional[pulumi.Input[int]] = None,
                 node_memory: Optional[pulumi.Input[int]] = None,
                 nodes: Optional[pulumi.Input[int]] = None,
                 opensearch: Optional[pulumi.Input['DatabaseOpensearchArgs']] = None,
                 pg: Optional[pulumi.Input['DatabasePgArgs']] = None,
                 plan: Optional[pulumi.Input[str]] = None,
                 redis: Optional[pulumi.Input['DatabaseRedisArgs']] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 termination_protection: Optional[pulumi.Input[bool]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 uri: Optional[pulumi.Input[str]] = None,
                 zone: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Database resources.
        :param pulumi.Input[str] ca_certificate: CA Certificate required to reach a DBaaS service through a TLS-protected connection.
        :param pulumi.Input[str] created_at: The creation date of the database service.
        :param pulumi.Input[int] disk_size: The disk size of the database service.
        :param pulumi.Input['DatabaseKafkaArgs'] kafka: *kafka* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[str] maintenance_dow: The day of week to perform the automated database service maintenance (`never`, `monday`, `tuesday`, `wednesday`, `thursday`, `friday`, `saturday`, `sunday`).
        :param pulumi.Input[str] maintenance_time: The time of day to perform the automated database service maintenance (`HH:MM:SS`)
        :param pulumi.Input['DatabaseMysqlArgs'] mysql: *mysql* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[str] name: The name of the database service.
        :param pulumi.Input[int] node_cpus: The number of CPUs of the database service.
        :param pulumi.Input[int] node_memory: The amount of memory of the database service.
        :param pulumi.Input[int] nodes: The number of nodes of the database service.
        :param pulumi.Input['DatabaseOpensearchArgs'] opensearch: *opensearch* database service type specific arguments. Structure is documented below.
        :param pulumi.Input['DatabasePgArgs'] pg: *pg* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[str] plan: The plan of the database service (use the [Exoscale CLI][cli] - `exo dbaas type show <TYPE>` - for reference).
        :param pulumi.Input['DatabaseRedisArgs'] redis: *redis* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[str] state: The current state of the database service.
        :param pulumi.Input[bool] termination_protection: The database service protection boolean flag against termination/power-off.
        :param pulumi.Input[str] type: The type of the database service (`kafka`, `mysql`, `opensearch`, `pg`, `redis`).
        :param pulumi.Input[str] updated_at: The date of the latest database service update.
        :param pulumi.Input[str] uri: The database service connection URI.
        :param pulumi.Input[str] zone: The Exoscale [Zone][zone] name.
        """
        if ca_certificate is not None:
            pulumi.set(__self__, "ca_certificate", ca_certificate)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if disk_size is not None:
            pulumi.set(__self__, "disk_size", disk_size)
        if kafka is not None:
            pulumi.set(__self__, "kafka", kafka)
        if maintenance_dow is not None:
            pulumi.set(__self__, "maintenance_dow", maintenance_dow)
        if maintenance_time is not None:
            pulumi.set(__self__, "maintenance_time", maintenance_time)
        if mysql is not None:
            pulumi.set(__self__, "mysql", mysql)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_cpus is not None:
            pulumi.set(__self__, "node_cpus", node_cpus)
        if node_memory is not None:
            pulumi.set(__self__, "node_memory", node_memory)
        if nodes is not None:
            pulumi.set(__self__, "nodes", nodes)
        if opensearch is not None:
            pulumi.set(__self__, "opensearch", opensearch)
        if pg is not None:
            pulumi.set(__self__, "pg", pg)
        if plan is not None:
            pulumi.set(__self__, "plan", plan)
        if redis is not None:
            pulumi.set(__self__, "redis", redis)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if termination_protection is not None:
            pulumi.set(__self__, "termination_protection", termination_protection)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if uri is not None:
            pulumi.set(__self__, "uri", uri)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter(name="caCertificate")
    def ca_certificate(self) -> Optional[pulumi.Input[str]]:
        """
        CA Certificate required to reach a DBaaS service through a TLS-protected connection.
        """
        return pulumi.get(self, "ca_certificate")

    @ca_certificate.setter
    def ca_certificate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ca_certificate", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        The creation date of the database service.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="diskSize")
    def disk_size(self) -> Optional[pulumi.Input[int]]:
        """
        The disk size of the database service.
        """
        return pulumi.get(self, "disk_size")

    @disk_size.setter
    def disk_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "disk_size", value)

    @property
    @pulumi.getter
    def kafka(self) -> Optional[pulumi.Input['DatabaseKafkaArgs']]:
        """
        *kafka* database service type specific arguments. Structure is documented below.
        """
        return pulumi.get(self, "kafka")

    @kafka.setter
    def kafka(self, value: Optional[pulumi.Input['DatabaseKafkaArgs']]):
        pulumi.set(self, "kafka", value)

    @property
    @pulumi.getter(name="maintenanceDow")
    def maintenance_dow(self) -> Optional[pulumi.Input[str]]:
        """
        The day of week to perform the automated database service maintenance (`never`, `monday`, `tuesday`, `wednesday`, `thursday`, `friday`, `saturday`, `sunday`).
        """
        return pulumi.get(self, "maintenance_dow")

    @maintenance_dow.setter
    def maintenance_dow(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "maintenance_dow", value)

    @property
    @pulumi.getter(name="maintenanceTime")
    def maintenance_time(self) -> Optional[pulumi.Input[str]]:
        """
        The time of day to perform the automated database service maintenance (`HH:MM:SS`)
        """
        return pulumi.get(self, "maintenance_time")

    @maintenance_time.setter
    def maintenance_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "maintenance_time", value)

    @property
    @pulumi.getter
    def mysql(self) -> Optional[pulumi.Input['DatabaseMysqlArgs']]:
        """
        *mysql* database service type specific arguments. Structure is documented below.
        """
        return pulumi.get(self, "mysql")

    @mysql.setter
    def mysql(self, value: Optional[pulumi.Input['DatabaseMysqlArgs']]):
        pulumi.set(self, "mysql", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the database service.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nodeCpus")
    def node_cpus(self) -> Optional[pulumi.Input[int]]:
        """
        The number of CPUs of the database service.
        """
        return pulumi.get(self, "node_cpus")

    @node_cpus.setter
    def node_cpus(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "node_cpus", value)

    @property
    @pulumi.getter(name="nodeMemory")
    def node_memory(self) -> Optional[pulumi.Input[int]]:
        """
        The amount of memory of the database service.
        """
        return pulumi.get(self, "node_memory")

    @node_memory.setter
    def node_memory(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "node_memory", value)

    @property
    @pulumi.getter
    def nodes(self) -> Optional[pulumi.Input[int]]:
        """
        The number of nodes of the database service.
        """
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "nodes", value)

    @property
    @pulumi.getter
    def opensearch(self) -> Optional[pulumi.Input['DatabaseOpensearchArgs']]:
        """
        *opensearch* database service type specific arguments. Structure is documented below.
        """
        return pulumi.get(self, "opensearch")

    @opensearch.setter
    def opensearch(self, value: Optional[pulumi.Input['DatabaseOpensearchArgs']]):
        pulumi.set(self, "opensearch", value)

    @property
    @pulumi.getter
    def pg(self) -> Optional[pulumi.Input['DatabasePgArgs']]:
        """
        *pg* database service type specific arguments. Structure is documented below.
        """
        return pulumi.get(self, "pg")

    @pg.setter
    def pg(self, value: Optional[pulumi.Input['DatabasePgArgs']]):
        pulumi.set(self, "pg", value)

    @property
    @pulumi.getter
    def plan(self) -> Optional[pulumi.Input[str]]:
        """
        The plan of the database service (use the [Exoscale CLI][cli] - `exo dbaas type show <TYPE>` - for reference).
        """
        return pulumi.get(self, "plan")

    @plan.setter
    def plan(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "plan", value)

    @property
    @pulumi.getter
    def redis(self) -> Optional[pulumi.Input['DatabaseRedisArgs']]:
        """
        *redis* database service type specific arguments. Structure is documented below.
        """
        return pulumi.get(self, "redis")

    @redis.setter
    def redis(self, value: Optional[pulumi.Input['DatabaseRedisArgs']]):
        pulumi.set(self, "redis", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state of the database service.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="terminationProtection")
    def termination_protection(self) -> Optional[pulumi.Input[bool]]:
        """
        The database service protection boolean flag against termination/power-off.
        """
        return pulumi.get(self, "termination_protection")

    @termination_protection.setter
    def termination_protection(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "termination_protection", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the database service (`kafka`, `mysql`, `opensearch`, `pg`, `redis`).
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        The date of the latest database service update.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter
    def uri(self) -> Optional[pulumi.Input[str]]:
        """
        The database service connection URI.
        """
        return pulumi.get(self, "uri")

    @uri.setter
    def uri(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "uri", value)

    @property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[str]]:
        """
        The Exoscale [Zone][zone] name.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "zone", value)


class Database(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 kafka: Optional[pulumi.Input[pulumi.InputType['DatabaseKafkaArgs']]] = None,
                 maintenance_dow: Optional[pulumi.Input[str]] = None,
                 maintenance_time: Optional[pulumi.Input[str]] = None,
                 mysql: Optional[pulumi.Input[pulumi.InputType['DatabaseMysqlArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 opensearch: Optional[pulumi.Input[pulumi.InputType['DatabaseOpensearchArgs']]] = None,
                 pg: Optional[pulumi.Input[pulumi.InputType['DatabasePgArgs']]] = None,
                 plan: Optional[pulumi.Input[str]] = None,
                 redis: Optional[pulumi.Input[pulumi.InputType['DatabaseRedisArgs']]] = None,
                 termination_protection: Optional[pulumi.Input[bool]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 zone: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Import

        An existing database service may be imported by `<name>@<zone>`console

        ```sh
         $ pulumi import exoscale:index/database:Database \\
        ```

         exoscale_database.my_database \\

         my-database@ch-gva-2

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['DatabaseKafkaArgs']] kafka: *kafka* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[str] maintenance_dow: The day of week to perform the automated database service maintenance (`never`, `monday`, `tuesday`, `wednesday`, `thursday`, `friday`, `saturday`, `sunday`).
        :param pulumi.Input[str] maintenance_time: The time of day to perform the automated database service maintenance (`HH:MM:SS`)
        :param pulumi.Input[pulumi.InputType['DatabaseMysqlArgs']] mysql: *mysql* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[str] name: The name of the database service.
        :param pulumi.Input[pulumi.InputType['DatabaseOpensearchArgs']] opensearch: *opensearch* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[pulumi.InputType['DatabasePgArgs']] pg: *pg* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[str] plan: The plan of the database service (use the [Exoscale CLI][cli] - `exo dbaas type show <TYPE>` - for reference).
        :param pulumi.Input[pulumi.InputType['DatabaseRedisArgs']] redis: *redis* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[bool] termination_protection: The database service protection boolean flag against termination/power-off.
        :param pulumi.Input[str] type: The type of the database service (`kafka`, `mysql`, `opensearch`, `pg`, `redis`).
        :param pulumi.Input[str] zone: The Exoscale [Zone][zone] name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DatabaseArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        An existing database service may be imported by `<name>@<zone>`console

        ```sh
         $ pulumi import exoscale:index/database:Database \\
        ```

         exoscale_database.my_database \\

         my-database@ch-gva-2

        :param str resource_name: The name of the resource.
        :param DatabaseArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatabaseArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 kafka: Optional[pulumi.Input[pulumi.InputType['DatabaseKafkaArgs']]] = None,
                 maintenance_dow: Optional[pulumi.Input[str]] = None,
                 maintenance_time: Optional[pulumi.Input[str]] = None,
                 mysql: Optional[pulumi.Input[pulumi.InputType['DatabaseMysqlArgs']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 opensearch: Optional[pulumi.Input[pulumi.InputType['DatabaseOpensearchArgs']]] = None,
                 pg: Optional[pulumi.Input[pulumi.InputType['DatabasePgArgs']]] = None,
                 plan: Optional[pulumi.Input[str]] = None,
                 redis: Optional[pulumi.Input[pulumi.InputType['DatabaseRedisArgs']]] = None,
                 termination_protection: Optional[pulumi.Input[bool]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 zone: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatabaseArgs.__new__(DatabaseArgs)

            __props__.__dict__["kafka"] = kafka
            __props__.__dict__["maintenance_dow"] = maintenance_dow
            __props__.__dict__["maintenance_time"] = maintenance_time
            __props__.__dict__["mysql"] = mysql
            __props__.__dict__["name"] = name
            __props__.__dict__["opensearch"] = opensearch
            __props__.__dict__["pg"] = pg
            if plan is None and not opts.urn:
                raise TypeError("Missing required property 'plan'")
            __props__.__dict__["plan"] = plan
            __props__.__dict__["redis"] = redis
            __props__.__dict__["termination_protection"] = termination_protection
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            if zone is None and not opts.urn:
                raise TypeError("Missing required property 'zone'")
            __props__.__dict__["zone"] = zone
            __props__.__dict__["ca_certificate"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["disk_size"] = None
            __props__.__dict__["node_cpus"] = None
            __props__.__dict__["node_memory"] = None
            __props__.__dict__["nodes"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["updated_at"] = None
            __props__.__dict__["uri"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["uri"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Database, __self__).__init__(
            'exoscale:index/database:Database',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ca_certificate: Optional[pulumi.Input[str]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            disk_size: Optional[pulumi.Input[int]] = None,
            kafka: Optional[pulumi.Input[pulumi.InputType['DatabaseKafkaArgs']]] = None,
            maintenance_dow: Optional[pulumi.Input[str]] = None,
            maintenance_time: Optional[pulumi.Input[str]] = None,
            mysql: Optional[pulumi.Input[pulumi.InputType['DatabaseMysqlArgs']]] = None,
            name: Optional[pulumi.Input[str]] = None,
            node_cpus: Optional[pulumi.Input[int]] = None,
            node_memory: Optional[pulumi.Input[int]] = None,
            nodes: Optional[pulumi.Input[int]] = None,
            opensearch: Optional[pulumi.Input[pulumi.InputType['DatabaseOpensearchArgs']]] = None,
            pg: Optional[pulumi.Input[pulumi.InputType['DatabasePgArgs']]] = None,
            plan: Optional[pulumi.Input[str]] = None,
            redis: Optional[pulumi.Input[pulumi.InputType['DatabaseRedisArgs']]] = None,
            state: Optional[pulumi.Input[str]] = None,
            termination_protection: Optional[pulumi.Input[bool]] = None,
            type: Optional[pulumi.Input[str]] = None,
            updated_at: Optional[pulumi.Input[str]] = None,
            uri: Optional[pulumi.Input[str]] = None,
            zone: Optional[pulumi.Input[str]] = None) -> 'Database':
        """
        Get an existing Database resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] ca_certificate: CA Certificate required to reach a DBaaS service through a TLS-protected connection.
        :param pulumi.Input[str] created_at: The creation date of the database service.
        :param pulumi.Input[int] disk_size: The disk size of the database service.
        :param pulumi.Input[pulumi.InputType['DatabaseKafkaArgs']] kafka: *kafka* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[str] maintenance_dow: The day of week to perform the automated database service maintenance (`never`, `monday`, `tuesday`, `wednesday`, `thursday`, `friday`, `saturday`, `sunday`).
        :param pulumi.Input[str] maintenance_time: The time of day to perform the automated database service maintenance (`HH:MM:SS`)
        :param pulumi.Input[pulumi.InputType['DatabaseMysqlArgs']] mysql: *mysql* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[str] name: The name of the database service.
        :param pulumi.Input[int] node_cpus: The number of CPUs of the database service.
        :param pulumi.Input[int] node_memory: The amount of memory of the database service.
        :param pulumi.Input[int] nodes: The number of nodes of the database service.
        :param pulumi.Input[pulumi.InputType['DatabaseOpensearchArgs']] opensearch: *opensearch* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[pulumi.InputType['DatabasePgArgs']] pg: *pg* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[str] plan: The plan of the database service (use the [Exoscale CLI][cli] - `exo dbaas type show <TYPE>` - for reference).
        :param pulumi.Input[pulumi.InputType['DatabaseRedisArgs']] redis: *redis* database service type specific arguments. Structure is documented below.
        :param pulumi.Input[str] state: The current state of the database service.
        :param pulumi.Input[bool] termination_protection: The database service protection boolean flag against termination/power-off.
        :param pulumi.Input[str] type: The type of the database service (`kafka`, `mysql`, `opensearch`, `pg`, `redis`).
        :param pulumi.Input[str] updated_at: The date of the latest database service update.
        :param pulumi.Input[str] uri: The database service connection URI.
        :param pulumi.Input[str] zone: The Exoscale [Zone][zone] name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatabaseState.__new__(_DatabaseState)

        __props__.__dict__["ca_certificate"] = ca_certificate
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["disk_size"] = disk_size
        __props__.__dict__["kafka"] = kafka
        __props__.__dict__["maintenance_dow"] = maintenance_dow
        __props__.__dict__["maintenance_time"] = maintenance_time
        __props__.__dict__["mysql"] = mysql
        __props__.__dict__["name"] = name
        __props__.__dict__["node_cpus"] = node_cpus
        __props__.__dict__["node_memory"] = node_memory
        __props__.__dict__["nodes"] = nodes
        __props__.__dict__["opensearch"] = opensearch
        __props__.__dict__["pg"] = pg
        __props__.__dict__["plan"] = plan
        __props__.__dict__["redis"] = redis
        __props__.__dict__["state"] = state
        __props__.__dict__["termination_protection"] = termination_protection
        __props__.__dict__["type"] = type
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["uri"] = uri
        __props__.__dict__["zone"] = zone
        return Database(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="caCertificate")
    def ca_certificate(self) -> pulumi.Output[str]:
        """
        CA Certificate required to reach a DBaaS service through a TLS-protected connection.
        """
        return pulumi.get(self, "ca_certificate")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        The creation date of the database service.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="diskSize")
    def disk_size(self) -> pulumi.Output[int]:
        """
        The disk size of the database service.
        """
        return pulumi.get(self, "disk_size")

    @property
    @pulumi.getter
    def kafka(self) -> pulumi.Output[Optional['outputs.DatabaseKafka']]:
        """
        *kafka* database service type specific arguments. Structure is documented below.
        """
        return pulumi.get(self, "kafka")

    @property
    @pulumi.getter(name="maintenanceDow")
    def maintenance_dow(self) -> pulumi.Output[str]:
        """
        The day of week to perform the automated database service maintenance (`never`, `monday`, `tuesday`, `wednesday`, `thursday`, `friday`, `saturday`, `sunday`).
        """
        return pulumi.get(self, "maintenance_dow")

    @property
    @pulumi.getter(name="maintenanceTime")
    def maintenance_time(self) -> pulumi.Output[str]:
        """
        The time of day to perform the automated database service maintenance (`HH:MM:SS`)
        """
        return pulumi.get(self, "maintenance_time")

    @property
    @pulumi.getter
    def mysql(self) -> pulumi.Output[Optional['outputs.DatabaseMysql']]:
        """
        *mysql* database service type specific arguments. Structure is documented below.
        """
        return pulumi.get(self, "mysql")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the database service.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nodeCpus")
    def node_cpus(self) -> pulumi.Output[int]:
        """
        The number of CPUs of the database service.
        """
        return pulumi.get(self, "node_cpus")

    @property
    @pulumi.getter(name="nodeMemory")
    def node_memory(self) -> pulumi.Output[int]:
        """
        The amount of memory of the database service.
        """
        return pulumi.get(self, "node_memory")

    @property
    @pulumi.getter
    def nodes(self) -> pulumi.Output[int]:
        """
        The number of nodes of the database service.
        """
        return pulumi.get(self, "nodes")

    @property
    @pulumi.getter
    def opensearch(self) -> pulumi.Output[Optional['outputs.DatabaseOpensearch']]:
        """
        *opensearch* database service type specific arguments. Structure is documented below.
        """
        return pulumi.get(self, "opensearch")

    @property
    @pulumi.getter
    def pg(self) -> pulumi.Output[Optional['outputs.DatabasePg']]:
        """
        *pg* database service type specific arguments. Structure is documented below.
        """
        return pulumi.get(self, "pg")

    @property
    @pulumi.getter
    def plan(self) -> pulumi.Output[str]:
        """
        The plan of the database service (use the [Exoscale CLI][cli] - `exo dbaas type show <TYPE>` - for reference).
        """
        return pulumi.get(self, "plan")

    @property
    @pulumi.getter
    def redis(self) -> pulumi.Output[Optional['outputs.DatabaseRedis']]:
        """
        *redis* database service type specific arguments. Structure is documented below.
        """
        return pulumi.get(self, "redis")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current state of the database service.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="terminationProtection")
    def termination_protection(self) -> pulumi.Output[Optional[bool]]:
        """
        The database service protection boolean flag against termination/power-off.
        """
        return pulumi.get(self, "termination_protection")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        The type of the database service (`kafka`, `mysql`, `opensearch`, `pg`, `redis`).
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        The date of the latest database service update.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def uri(self) -> pulumi.Output[str]:
        """
        The database service connection URI.
        """
        return pulumi.get(self, "uri")

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Output[str]:
        """
        The Exoscale [Zone][zone] name.
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetInstancePoolListResult',
    'AwaitableGetInstancePoolListResult',
    'get_instance_pool_list',
    'get_instance_pool_list_output',
]

@pulumi.output_type
class GetInstancePoolListResult:
    """
    A collection of values returned by getInstancePoolList.
    """
    def __init__(__self__, id=None, pools=None, zone=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if pools and not isinstance(pools, list):
            raise TypeError("Expected argument 'pools' to be a list")
        pulumi.set(__self__, "pools", pools)
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def pools(self) -> Sequence['outputs.GetInstancePoolListPoolResult']:
        """
        The list of exoscale_instance_pool.
        """
        return pulumi.get(self, "pools")

    @property
    @pulumi.getter
    def zone(self) -> str:
        return pulumi.get(self, "zone")


class AwaitableGetInstancePoolListResult(GetInstancePoolListResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstancePoolListResult(
            id=self.id,
            pools=self.pools,
            zone=self.zone)


def get_instance_pool_list(zone: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstancePoolListResult:
    """
    Use this data source to access information about an existing resource.

    :param str zone: The Exoscale [Zone][zone] name.
    """
    __args__ = dict()
    __args__['zone'] = zone
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('exoscale:index/getInstancePoolList:getInstancePoolList', __args__, opts=opts, typ=GetInstancePoolListResult).value

    return AwaitableGetInstancePoolListResult(
        id=__ret__.id,
        pools=__ret__.pools,
        zone=__ret__.zone)


@_utilities.lift_output_func(get_instance_pool_list)
def get_instance_pool_list_output(zone: Optional[pulumi.Input[str]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetInstancePoolListResult]:
    """
    Use this data source to access information about an existing resource.

    :param str zone: The Exoscale [Zone][zone] name.
    """
    ...
